# About Coventry

Coventry is a simple to setup IP telephony server for residential gateways and
small office users. Coventry interconnects SIP users and devices with advanced
voice, messaging, and facility automation services. Coventry would be used
either stand-alone, such as off-grid facilities or boats, or connected thru
upstream adapters to a carrier provider, a residential apartment complex
switch, a SIP trunking provider, etc.

Other potential uses include remote property management, connecting security
services, and general home automation. Coventry is meant to be runnable on
gnu/linux servers and routers or in a container. My preferred installation
target is a dedicated 32 bit arm device running Alpine Linux. A 2 digit local
dialing plan and a maximum of 80 locally connected sip devices are supported.

When used as a residential ip telephony gateway Coventry may not include
dedicated operator consoles or application services. Simple common residential
style ringing would be used for external calls. A local sip application or
media server like Bordeaux could be added to Coventry. Otherwise application
services would likely be externally hosted. External connections such as to the
PSTN would also typically be handled thru an upstream adapter.

Coventry originally was a small stand-alone gnu sipwitch VoIP wifi access point
for use on early Raspberry Pi's first deployed in 2013. A few were made for
residential use at the time, and I also used it when speaking at conferences.
The new Coventry codebase has no common code with gnu sipwitch, but it does use
ideas from the development of SipWitchQt, including a simplified threaded event
driven actor messaging system and shared pointer objects to avoid lock
contention, but it does so using only the c++17 standard library.

## Dependencies

Coventry is a C++17 application that requires CMake to build and requires
moderncli and libfmt to be installed. Coventry also requires OpenSSL,
libeXosip2 (5.3.0 or later), and supporting libraries for those. Coventry can
run on any platform with true Posix support, such as all Linux kernel based
systems, BSD's, and maybe even MacOS, as long as Posix message queues are
supported. Coventry can be compiled and ran using GCC (9 or later), Clang (14?
or later), or any other C++ runtime with thread and filesystem support.

Coventry will run directly on NetBSD (10), and also on FreeBSD if the mqueuefs
kernel module is loaded. Coventry will not currently run on OpenBSD, which
lacks posix message queue support, though we may adopt using a fifo in the
future for it. Coventry will also not build or run with MSVC or on Microsoft
Windows. A MingW build may compile with gcc and run on Microsoft Windows, but
this has never been tested.

Coventry may also optionally use libsystemd on GNU/Linux systems. This allows
building for optimized use on distros that use systemd. A systemd enabled
binary can also run on non-systemd distros, but it is recommended not to enable
systemd support for any GNU/Linux distro that does not default to systemd as
it increases the attack surface for potential vulnerabilities.

## Distributions

Distributions of this package are provided as detached source tarballs made
from a tagged release from our internal source repository. These stand-alone
detached tarballs can be used to make packages for many GNU/Linux systems, and
for BSD ports. They may also be used to build and install the software directly
on a target platform.

The latest public release source tarball can be found at either
https://www.tychosoft.com/tychosoft/-/packages/generic/coventry or thru an
auto-generated tarball from the projects public gitlab release page, both which
provides access to past releases as well.

## Installation

**Installation should only be attempted with cmake release builds**. The
preferred cmake build type for live installations is `cmake -D
CMAKE_BUILD_TYPE=RelWithDebugInfo .`. This retains debug symbols in release
builds which many gnu/linux packaging systems then strip off and separately
generate a debug package.

Many paths are set by cmake configuration for release builds, and these can be
overridden using `CMAKE -D... .` overrides. Some of these are listed with the
--version option, so you can always find what paths a given coventry binary has
been built for to use.

## Participation

This project is offered as free (as in freedom) software for public use and has
a public project page at https://www.gitlab.com/tychosoft/coventry which has
an issue tracker where people can submit public bug reports, a wiki for hosting
project documentation, and a public git repository. Patches and merge
requests may be submitted in the issue tracker or thru email. Support requests
and other kinds of inquiries may also be sent thru the tychosoft gitlab help
desktop service. Other details about participation may be found in the
Contributing page.

## Testing

When `cmake -DCMAKE_BUILD_TYPE=Debug .` is used to produce a Debug build it can
be executed directly for testing from the server build directory such as with
`./src/coventry -vvvv`, no further install is required. The debug build uses
the config file found in the test/ directory, and a test/custom.conf file can
be added with configuration overrides for local developer testing.

The `test` target runs a unit test framework. At the moment this only verifies
some of the header libraries. It may be extended to support component level
unit testing in the future.

A simple test/custom.conf to test your server might look like:

```
[server]
algorithm = md5
expires = 2m

[20]
name = dyfet
display = David Sugar
password = XXX

[89]
name = bordeaux
display = Bordeaux
password = XXX
lines = 20
```

For clients, the user id used for authentication is the same as the extension
number, and Coventry should be in the default route or set as default proxy.

